parse_args

Function parse_args 

pub fn parse_args(args: &[String]) -> Result<Action, CliError>
Parses a command line, without the program name.

Errors

Returns the message to print when the arguments do not name a compilation this compiler can attempt.