run

Function run 

pub fn run(args: &[String]) -> i32
Runs the driver and returns the process exit code.

args excludes the program name. Output goes to stdout and errors to stderr, which is the one place in the compiler that is true.