pub enum Error {
NoLinker {
tried: Vec<String>,
},
Named {
name: String,
},
Target {
triple: String,
},
Spawn {
path: String,
why: String,
},
Refused {
status: String,
},
}Expand description
Why a link could not be run.
Variants
NoLinker
No linker was found, after looking everywhere there was to look.
Named
-fuse-ld= named one that is not on this machine.
Target
A target this does not know how to build a link line for.
Spawn
The linker was found and could not be started.
Refused
The linker ran and said no.