pub fn parse_args(args: &[String]) -> Result<Action, CliError>
Parses a command line, without the program name.
Returns the message to print when the arguments do not name a compilation this compiler can attempt.